==> xml_layout-0.0.1.tar.gz: lib/types/image.dart <==

import 'dart:io';
import 'dart:typed_data';

import 'package:flutter/material.dart';

import '../xml_layout.dart';

void reg() {
  XMLLayout.reg(Image, (node, key) {
    return Image(
      key: key,
      image: node.s<ImageProvider>("image"),
      frameBuilder: node.s<ImageFrameBuilder>("frameBuilder"),
      errorBuilder: node.s<ImageErrorWidgetBuilder>("errorBuilder"),
      semanticLabel: node.s<String>("semanticLabel"),
      excludeFromSemantics: node.s<bool>("excludeFromSemantics", false),
      width: node.s<double>("width"),
      height: node.s<double>("height"),
      color: node.s<Color>("color"),
      colorBlendMode: node.s<BlendMode>("colorBlendMode"),
      fit: node.s<BoxFit>("fit"),
      alignment: node.s<Alignment>("alignment", Alignment.center),
      repeat: node.s<ImageRepeat>("repeat", ImageRepeat.noRepeat),
      centerSlice: node.s<Rect>("centerSlice"),
      matchTextDirection: node.s<bool>("matchTextDirection", false),
      gaplessPlayback: node.s<bool>("gaplessPlayback", false),
      filterQuality: node.s<FilterQuality>("filterQuality", FilterQuality.low),
      loadingBuilder: node.s<ImageLoadingBuilder>("loadingBuilder"),
    );
  }, mode: XMLLayout.Element);
  XMLLayout.regEnum(ImageRepeat.values);
  XMLLayout.regEnum(FilterQuality.values);
  XMLLayout.reg("Image.network", (node, key) {
    return Image.network(
      node.s<String>("src"),
      key: key,
      frameBuilder: node.s<ImageFrameBuilder>("frameBuilder"),
      errorBuilder: node.s<ImageErrorWidgetBuilder>("errorBuilder"),
      semanticLabel: node.s<String>("semanticLabel"),
      excludeFromSemantics: node.s<bool>("excludeFromSemantics", false),
      width: node.s<double>("width"),
      height: node.s<double>("height"),
      color: node.s<Color>("color"),
      colorBlendMode: node.s<BlendMode>("colorBlendMode"),
      fit: node.s<BoxFit>("fit"),
      alignment: node.s<Alignment>("alignment", Alignment.center),
      repeat: node.s<ImageRepeat>("repeat", ImageRepeat.noRepeat),
      centerSlice: node.s<Rect>("centerSlice"),
      matchTextDirection: node.s<bool>("matchTextDirection", false),
      gaplessPlayback: node.s<bool>("gaplessPlayback", false),
      filterQuality: node.s<FilterQuality>("filterQuality", FilterQuality.low),
      loadingBuilder: node.s<ImageLoadingBuilder>("loadingBuilder"),
      cacheWidth: node.s<int>("cacheWidth"),
      cacheHeight: node.s<int>("cacheHeight"),

      scale: node.s<double>("scale"),
      headers: node.s<Map<String, String>>("headers"),

    );
  });
  XMLLayout.reg("Image.file", (node, key) {
    return Image.file(
      node.s<File>("Image.file"),
      key: key,
      frameBuilder: node.s<ImageFrameBuilder>("frameBuilder"),
      errorBuilder: node.s<ImageErrorWidgetBuilder>("errorBuilder"),
      semanticLabel: node.s<String>("semanticLabel"),
      excludeFromSemantics: node.s<bool>("excludeFromSemantics", false),
      width: node.s<double>("width"),
      height: node.s<double>("height"),
      color: node.s<Color>("color"),
      colorBlendMode: node.s<BlendMode>("colorBlendMode"),
      fit: node.s<BoxFit>("fit"),
      alignment: node.s<Alignment>("alignment", Alignment.center),
      repeat: node.s<ImageRepeat>("repeat", ImageRepeat.noRepeat),
      centerSlice: node.s<Rect>("centerSlice"),
      matchTextDirection: node.s<bool>("matchTextDirection", false),
      gaplessPlayback: node.s<bool>("gaplessPlayback", false),
      filterQuality: node.s<FilterQuality>("filterQuality", FilterQuality.low),
      cacheWidth: node.s<int>("cacheWidth"),
      cacheHeight: node.s<int>("cacheHeight"),

      scale: node.s<double>("scale"),
    );
  });
  XMLLayout.reg("Image.asset", (node, key) {
    return Image.asset(
      node.s<String>("name"),
      key: key,
      frameBuilder: node.s<ImageFrameBuilder>("frameBuilder"),
      errorBuilder: node.s<ImageErrorWidgetBuilder>("errorBuilder"),
      semanticLabel: node.s<String>("semanticLabel"),
      excludeFromSemantics: node.s<bool>("excludeFromSemantics", false),
      width: node.s<double>("width"),
      height: node.s<double>("height"),
      color: node.s<Color>("color"),
      colorBlendMode: node.s<BlendMode>("colorBlendMode"),
      fit: node.s<BoxFit>("fit"),
      alignment: node.s<Alignment>("alignment", Alignment.center),
      repeat: node.s<ImageRepeat>("repeat", ImageRepeat.noRepeat),
      centerSlice: node.s<Rect>("centerSlice"),
      matchTextDirection: node.s<bool>("matchTextDirection", false),
      gaplessPlayback: node.s<bool>("gaplessPlayback", false),
      filterQuality: node.s<FilterQuality>("filterQuality", FilterQuality.low),
      cacheWidth: node.s<int>("cacheWidth"),
      cacheHeight: node.s<int>("cacheHeight"),

      scale: node.s<double>("scale"),
      package: node.s<String>("package")
    );
  });
  XMLLayout.reg("Image.memory", (node, key) {
    return Image.memory(
      node.s<Uint8List>("bytes"),
      key: key,
      frameBuilder: node.s<ImageFrameBuilder>("frameBuilder"),
      errorBuilder: node.s<ImageErrorWidgetBuilder>("errorBuilder"),
      semanticLabel: node.s<String>("semanticLabel"),
      excludeFromSemantics: node.s<bool>("excludeFromSemantics", false),
      width: node.s<double>("width"),
      height: node.s<double>("height"),
      color: node.s<Color>("color"),
      colorBlendMode: node.s<BlendMode>("colorBlendMode"),
      fit: node.s<BoxFit>("fit"),
      alignment: node.s<Alignment>("alignment", Alignment.center),
      repeat: node.s<ImageRepeat>("repeat", ImageRepeat.noRepeat),
      centerSlice: node.s<Rect>("centerSlice"),
      matchTextDirection: node.s<bool>("matchTextDirection", false),
      gaplessPlayback: node.s<bool>("gaplessPlayback", false),
      filterQuality: node.s<FilterQuality>("filterQuality", FilterQuality.low),
      cacheWidth: node.s<int>("cacheWidth"),
      cacheHeight: node.s<int>("cacheHeight"),

      scale: node.s<double>("scale"),
    );
  });
}

==> xml_layout-0.1.0.tar.gz: lib/types/image.dart <==

import 'dart:io';
import 'dart:typed_data';

import 'package:flutter/material.dart';

import '../xml_layout.dart';

void reg() {
  XmlLayout.reg(Image, (node, key) {
    return Image(
      key: key,
      image: node.s<ImageProvider>("image"),
      frameBuilder: node.s<ImageFrameBuilder>("frameBuilder"),
      errorBuilder: node.s<ImageErrorWidgetBuilder>("errorBuilder"),
      semanticLabel: node.s<String>("semanticLabel"),
      excludeFromSemantics: node.s<bool>("excludeFromSemantics", false),
      width: node.s<double>("width"),
      height: node.s<double>("height"),
      color: node.s<Color>("color"),
      colorBlendMode: node.s<BlendMode>("colorBlendMode"),
      fit: node.s<BoxFit>("fit"),
      alignment: node.s<Alignment>("alignment", Alignment.center),
      repeat: node.s<ImageRepeat>("repeat", ImageRepeat.noRepeat),
      centerSlice: node.s<Rect>("centerSlice"),
      matchTextDirection: node.s<bool>("matchTextDirection", false),
      gaplessPlayback: node.s<bool>("gaplessPlayback", false),
      filterQuality: node.s<FilterQuality>("filterQuality", FilterQuality.low),
      loadingBuilder: node.s<ImageLoadingBuilder>("loadingBuilder"),
    );
  }, mode: XmlLayout.Element);
  XmlLayout.regEnum(ImageRepeat.values);
  XmlLayout.regEnum(FilterQuality.values);
  XmlLayout.reg("Image.network", (node, key) {
    return Image.network(
      node.s<String>("src"),
      key: key,
      frameBuilder: node.s<ImageFrameBuilder>("frameBuilder"),
      errorBuilder: node.s<ImageErrorWidgetBuilder>("errorBuilder"),
      semanticLabel: node.s<String>("semanticLabel"),
      excludeFromSemantics: node.s<bool>("excludeFromSemantics", false),
      width: node.s<double>("width"),
      height: node.s<double>("height"),
      color: node.s<Color>("color"),
      colorBlendMode: node.s<BlendMode>("colorBlendMode"),
      fit: node.s<BoxFit>("fit"),
      alignment: node.s<Alignment>("alignment", Alignment.center),
      repeat: node.s<ImageRepeat>("repeat", ImageRepeat.noRepeat),
      centerSlice: node.s<Rect>("centerSlice"),
      matchTextDirection: node.s<bool>("matchTextDirection", false),
      gaplessPlayback: node.s<bool>("gaplessPlayback", false),
      filterQuality: node.s<FilterQuality>("filterQuality", FilterQuality.low),
      loadingBuilder: node.s<ImageLoadingBuilder>("loadingBuilder"),
      cacheWidth: node.s<int>("cacheWidth"),
      cacheHeight: node.s<int>("cacheHeight"),

      scale: node.s<double>("scale"),
      headers: node.s<Map<String, String>>("headers"),

    );
  });
  XmlLayout.reg("Image.file", (node, key) {
    return Image.file(
      node.s<File>("Image.file"),
      key: key,
      frameBuilder: node.s<ImageFrameBuilder>("frameBuilder"),
      errorBuilder: node.s<ImageErrorWidgetBuilder>("errorBuilder"),
      semanticLabel: node.s<String>("semanticLabel"),
      excludeFromSemantics: node.s<bool>("excludeFromSemantics", false),
      width: node.s<double>("width"),
      height: node.s<double>("height"),
      color: node.s<Color>("color"),
      colorBlendMode: node.s<BlendMode>("colorBlendMode"),
      fit: node.s<BoxFit>("fit"),
      alignment: node.s<Alignment>("alignment", Alignment.center),
      repeat: node.s<ImageRepeat>("repeat", ImageRepeat.noRepeat),
      centerSlice: node.s<Rect>("centerSlice"),
      matchTextDirection: node.s<bool>("matchTextDirection", false),
      gaplessPlayback: node.s<bool>("gaplessPlayback", false),
      filterQuality: node.s<FilterQuality>("filterQuality", FilterQuality.low),
      cacheWidth: node.s<int>("cacheWidth"),
      cacheHeight: node.s<int>("cacheHeight"),

      scale: node.s<double>("scale"),
    );
  });
  XmlLayout.reg("Image.asset", (node, key) {
    return Image.asset(
      node.s<String>("name"),
      key: key,
      frameBuilder: node.s<ImageFrameBuilder>("frameBuilder"),
      errorBuilder: node.s<ImageErrorWidgetBuilder>("errorBuilder"),
      semanticLabel: node.s<String>("semanticLabel"),
      excludeFromSemantics: node.s<bool>("excludeFromSemantics", false),
      width: node.s<double>("width"),
      height: node.s<double>("height"),
      color: node.s<Color>("color"),
      colorBlendMode: node.s<BlendMode>("colorBlendMode"),
      fit: node.s<BoxFit>("fit"),
      alignment: node.s<Alignment>("alignment", Alignment.center),
      repeat: node.s<ImageRepeat>("repeat", ImageRepeat.noRepeat),
      centerSlice: node.s<Rect>("centerSlice"),
      matchTextDirection: node.s<bool>("matchTextDirection", false),
      gaplessPlayback: node.s<bool>("gaplessPlayback", false),
      filterQuality: node.s<FilterQuality>("filterQuality", FilterQuality.low),
      cacheWidth: node.s<int>("cacheWidth"),
      cacheHeight: node.s<int>("cacheHeight"),

      scale: node.s<double>("scale"),
      package: node.s<String>("package")
    );
  });
  XmlLayout.reg("Image.memory", (node, key) {
    return Image.memory(
      node.s<Uint8List>("bytes"),
      key: key,
      frameBuilder: node.s<ImageFrameBuilder>("frameBuilder"),
      errorBuilder: node.s<ImageErrorWidgetBuilder>("errorBuilder"),
      semanticLabel: node.s<String>("semanticLabel"),
      excludeFromSemantics: node.s<bool>("excludeFromSemantics", false),
      width: node.s<double>("width"),
      height: node.s<double>("height"),
      color: node.s<Color>("color"),
      colorBlendMode: node.s<BlendMode>("colorBlendMode"),
      fit: node.s<BoxFit>("fit"),
      alignment: node.s<Alignment>("alignment", Alignment.center),
      repeat: node.s<ImageRepeat>("repeat", ImageRepeat.noRepeat),
      centerSlice: node.s<Rect>("centerSlice"),
      matchTextDirection: node.s<bool>("matchTextDirection", false),
      gaplessPlayback: node.s<bool>("gaplessPlayback", false),
      filterQuality: node.s<FilterQuality>("filterQuality", FilterQuality.low),
      cacheWidth: node.s<int>("cacheWidth"),
      cacheHeight: node.s<int>("cacheHeight"),

      scale: node.s<double>("scale"),
    );
  });
}
